Module time

Module time 

Temporal quantification.

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
TryFromFloatSecsError
An error which can be returned when converting a floating-point value of seconds into a Duration.