Temporal quantification.
Structs
- Duration
- A
Durationtype to represent a span of time, typically used for system timeouts. - Instant
- A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
- TryFrom
Float Secs Error - An error which can be returned when converting a floating-point value of seconds
into a
Duration.